"""
Custom wagtail settings, defined per-site
"""

import json

from cjkcms.models.snippet_models import Footer, Navbar
from cjkcms.settings import cms_settings
from django.db import models
from django.utils.translation import gettext_lazy as _
from modelcluster.fields import ParentalKey
from modelcluster.models import ClusterableModel
from wagtail.admin.panels import FieldPanel, MultiFieldPanel, HelpPanel, InlinePanel
from wagtail.contrib.settings.models import BaseSiteSetting, register_setting
from wagtail.images import get_image_model_string
from wagtail.models import Orderable


@register_setting(icon="group")
class SocialMediaSettings(BaseSiteSetting):
    """
    Social media accounts.
    """

    class Meta:
        verbose_name = _("Social Media")
        app_label = "cjkcms"

    facebook = models.URLField(
        blank=True,
        verbose_name=_("Facebook"),
        help_text=_("Your Facebook page URL"),
    )
    twitter = models.URLField(
        blank=True,
        verbose_name=_("Twitter"),
        help_text=_("Your Twitter page URL"),
    )
    instagram = models.CharField(
        max_length=255,
        blank=True,
        verbose_name=_("Instagram"),
        help_text=_("Your Instagram username, without the @"),
    )
    linkedin = models.URLField(
        blank=True,
        verbose_name=_("LinkedIn"),
        help_text=_("Your LinkedIn page URL"),
    )
    youtube = models.URLField(
        blank=True,
        verbose_name=_("YouTube"),
        help_text=_("Your YouTube channel or user account URL"),
    )
    vimeo = models.URLField(
        blank=True,
        verbose_name=_("Vimeo"),
        help_text=_("Your Vimeo channel or user account URL"),
    )

    location = models.CharField(
        blank=True,
        max_length=50,
        choices=cms_settings.CJKCMS_SOC_LOCATION_CHOICES,
        default=cms_settings.CJKCMS_SOC_LOCATION_DEFAULT,
        verbose_name=_("Location of social media block"),
    )

    @property
    def twitter_handle(self):
        """
        Gets the handle of the twitter account from a URL.
        """
        return self.twitter.strip().strip("/").split("/")[-1]

    @property
    def social_json(self):
        """
        Returns non-blank social accounts as a JSON list.
        """
        socialist = [
            self.facebook,
            self.twitter,
            self.instagram,
            self.youtube,
            self.linkedin,
            self.vimeo,
        ]
        socialist = list(filter(None, socialist))
        return json.dumps(socialist)

    panels = [
        MultiFieldPanel(
            [
                FieldPanel("facebook"),
                FieldPanel("twitter"),
                FieldPanel("instagram"),
                FieldPanel("linkedin"),
                FieldPanel("youtube"),
                FieldPanel("vimeo"),
            ],
            _("Social Media Accounts"),
        ),
        FieldPanel("location"),
    ]


@register_setting(icon="grip")
class LayoutSettings(ClusterableModel, BaseSiteSetting):
    """
    Branding, navbar, and theme settings.
    """

    class Meta:
        verbose_name = _("Layout")

    logo = models.ForeignKey(
        get_image_model_string(),
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name="+",
        verbose_name=_("Logo"),
        help_text=_("Brand logo used in the navbar and throughout the site"),
    )
    favicon = models.ForeignKey(
        get_image_model_string(),
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name="favicon",
        verbose_name=_("Favicon"),
    )
    navbar_color_scheme = models.CharField(
        blank=True,
        max_length=50,
        choices=None,
        default="",
        verbose_name=_("Navbar color scheme"),
        help_text=_(
            "Optimizes text and other navbar elements for use with light or dark backgrounds."
        ),  # noqa
    )
    navbar_class = models.CharField(
        blank=True,
        max_length=255,
        default="",
        verbose_name=_("Navbar CSS class"),
        help_text=_(
            'Custom classes applied to navbar e.g. "bg-light", "bg-dark", "bg-primary".'
        ),
    )
    navbar_fixed = models.BooleanField(
        default=False,
        verbose_name=_("Fixed navbar"),
        help_text=_("Fixed navbar will remain at the top of the page when scrolling."),
    )
    navbar_wrapper_fluid = models.BooleanField(
        default=True,
        verbose_name=_("Full width navbar"),
        help_text=_("The navbar will fill edge to edge."),
    )
    navbar_content_fluid = models.BooleanField(
        default=False,
        verbose_name=_("Full width navbar contents"),
        help_text=_("Content within the navbar will fill edge to edge."),
    )
    navbar_collapse_mode = models.CharField(
        blank=True,
        max_length=50,
        choices=None,
        default="",
        verbose_name=_("Collapse navbar menu"),
        help_text=_(
            "Control on what screen sizes to show and collapse the navbar menu links."
        ),
    )
    navbar_format = models.CharField(
        blank=True,
        max_length=50,
        choices=None,
        default="",
        verbose_name=_("Navbar format"),
    )
    navbar_search = models.BooleanField(
        default=True,
        verbose_name=_("Search box"),
        help_text=_("Show search box in navbar"),
    )
    navbar_langselector = models.CharField(
        blank=True,
        null=True,
        max_length=255,
        choices=None,
        default=None,
        verbose_name=_("Language selector"),
        help_text=_("Choose lang choice selector"),
    )

    frontend_theme = models.CharField(
        blank=True,
        max_length=50,
        choices=None,
        default="",
        verbose_name=_("Theme variant"),
        help_text=cms_settings.CJKCMS_FRONTEND_THEME_HELP,
    )

    awesome_cdn = models.BooleanField(
        default=False,
        verbose_name=_("Font Awesome"),
        help_text=_("Load font awesome from CDN"),
    )

    bootstrap_icons = models.BooleanField(
        default=False,
        verbose_name=_("Bootstrap Icons CSS"),
        help_text=_("Load bootstrap icons css from local/static folder"),
    )

    custom_font = models.BooleanField(
        default=False,
        verbose_name=_("Use custom font"),
        help_text=_("Custom body font e.g. from CDN & include css body override"),
    )

    font_url = models.CharField(
        blank=True,
        max_length=250,
        default=cms_settings.CJKCMS_FONT_URL,
        verbose_name=_("Font URL"),
        help_text=_("Full URL to font css file"),
    )

    font_family = models.CharField(
        blank=True,
        max_length=128,
        default=cms_settings.CJKCMS_FONT_FAMILY,
        verbose_name=_("Font Family"),
        help_text=_("Font family name, e.g. 'Open Sans, sans-serif'"),
    )

    base_template = models.CharField(
        blank=True,
        max_length=200,
        default=cms_settings.CJKCMS_BASE_TEMPLATE_DEFAULT,
        verbose_name=_("Base template"),
        help_text=cms_settings.CJKCMS_BASE_TEMPLATE_HELP,
    )

    articles_show_author = models.BooleanField(
        default=True,
        verbose_name=_("Show author in articles"),
        help_text=_("If disabled, override by filling `display author as` in article"),
    )

    articles_date_format = models.CharField(
        blank=True,
        max_length=200,
        default="Y-m-d",
        verbose_name=_("Date format in articles"),
        help_text=_("Format of the publication date in articles. Set blank to hide."),
    )

    panels = [
        MultiFieldPanel(
            [
                FieldPanel("logo"),
                FieldPanel("favicon"),
            ],
            heading=_("Branding"),
        ),
        InlinePanel(
            "site_navbar",
            help_text=_("Choose one or more navbars"),
            heading=_("Site Navbars"),
        ),
        MultiFieldPanel(
            [
                FieldPanel("navbar_color_scheme"),
                FieldPanel("navbar_class"),
                FieldPanel("navbar_fixed"),
                FieldPanel("navbar_wrapper_fluid"),
                FieldPanel("navbar_content_fluid"),
                FieldPanel("navbar_collapse_mode"),
                FieldPanel("navbar_format"),
                FieldPanel("navbar_search"),
                FieldPanel("navbar_langselector"),
            ],
            heading=_("Site Navbar Layout"),
        ),
        InlinePanel(
            "site_footer",
            help_text=_("Choose one or more footers"),
            heading=_("Site Footers"),
        ),
        MultiFieldPanel(
            [
                FieldPanel("frontend_theme"),
                FieldPanel("base_template"),
                FieldPanel("awesome_cdn"),
                FieldPanel("bootstrap_icons"),
                FieldPanel("custom_font"),
                FieldPanel("font_url"),
                FieldPanel("font_family"),
            ],
            heading=_("Theming"),
        ),
        MultiFieldPanel(
            [
                FieldPanel("articles_show_author"),
                FieldPanel("articles_date_format"),
            ],
            heading=_("Article Pages"),
        ),
    ]

    def __init__(self, *args, **kwargs):
        """
        Inject custom choices and defaults into the form fields
        to enable customization of settings without causing migration issues.
        """
        super().__init__(*args, **kwargs)
        # Set choices dynamically.
        self._meta.get_field(
            "frontend_theme"
        ).choices = cms_settings.CJKCMS_FRONTEND_THEME_CHOICES  # type: ignore
        self._meta.get_field(
            "navbar_collapse_mode"
        ).choices = cms_settings.CJKCMS_FRONTEND_NAVBAR_COLLAPSE_MODE_CHOICES  # type: ignore
        self._meta.get_field(
            "navbar_color_scheme"
        ).choices = cms_settings.CJKCMS_FRONTEND_NAVBAR_COLOR_SCHEME_CHOICES  # type: ignore
        self._meta.get_field(
            "navbar_format"
        ).choices = cms_settings.CJKCMS_FRONTEND_NAVBAR_FORMAT_CHOICES  # type: ignore
        self._meta.get_field(
            "navbar_langselector"
        ).choices = cms_settings.CJKCMS_LANGUAGE_SELECTOR_CHOICES  # type: ignore
        # Set default dynamically.
        if not self.id:  # type: ignore # if new record / id not yet assigned
            self.frontend_theme = cms_settings.CJKCMS_FRONTEND_THEME_DEFAULT
            self.navbar_class = cms_settings.CJKCMS_FRONTEND_NAVBAR_CLASS_DEFAULT
            self.navbar_collapse_mode = (
                cms_settings.CJKCMS_FRONTEND_NAVBAR_COLLAPSE_MODE_DEFAULT
            )
            self.navbar_color_scheme = (
                cms_settings.CJKCMS_FRONTEND_NAVBAR_COLOR_SCHEME_DEFAULT
            )
            self.navbar_format = cms_settings.CJKCMS_FRONTEND_NAVBAR_FORMAT_DEFAULT
            self.base_template = cms_settings.CJKCMS_BASE_TEMPLATE_DEFAULT


class NavbarOrderable(Orderable, models.Model):
    navbar_chooser = ParentalKey(
        LayoutSettings, related_name="site_navbar", verbose_name=_("Site Navbars")
    )
    navbar = models.ForeignKey(
        Navbar,
        blank=True,
        null=True,
        on_delete=models.CASCADE,
    )

    panels = [FieldPanel("navbar")]


class FooterOrderable(Orderable, models.Model):
    footer_chooser = ParentalKey(
        LayoutSettings, related_name="site_footer", verbose_name=_("Site Footers")
    )
    footer = models.ForeignKey(
        Footer,
        blank=True,
        null=True,
        on_delete=models.CASCADE,
    )

    panels = [FieldPanel("footer")]


@register_setting(icon="history")
class AnalyticsSettings(BaseSiteSetting):
    """
    Tracking and Google Analytics.
    """

    class Meta:
        verbose_name = _("Tracking")

    g4_tracking_id = models.CharField(
        blank=True,
        max_length=255,
        verbose_name=_("G4 Analytics Tracking ID"),
        help_text=_(
            'G4 Google Analytics tracking ID ("G-..."). If both G4 & UA set, both will be used.'
        ),
    )
    ga_track_button_clicks = models.BooleanField(
        default=False,
        verbose_name=_("Track button clicks"),
        help_text=_(
            "Track all button clicks using Google Analytics event tracking. "
            "Event tracking details can be specified in each button’s advanced settings options."
        ),  # noqa
    )
    gtm_id = models.CharField(
        blank=True,
        max_length=255,
        verbose_name=_("Google Tag Manager ID"),
        help_text=_('Begins with "GTM-"'),
    )
    matomo_hostname = models.CharField(
        blank=True,
        max_length=128,
        verbose_name=_("Hostname (including http(s)://)"),
        help_text=_(
            "Matomo hostname (e.g. https://tracker.com). Without trailing slash."
        ),
    )
    matomo_site_id = models.IntegerField(
        blank=True,
        null=True,
        verbose_name=_("Site ID"),
        help_text=_("Numeric site id from Matomo website configuration."),
    )
    matomo_disable_cookies = models.BooleanField(
        default=False,
        verbose_name=_("Disable Matomo Cookies"),
        help_text=_("Disable Matomo cookies. Useful for GDPR compliance."),  # noqa
    )
    # Cookie consent - using https://github.com/orestbida/cookieconsent (MIT license)
    cookie_consent = models.BooleanField(
        default=False,
        verbose_name=_("Enable cookie consent"),
        help_text=_(
            "Enable simple GDPR compliant cookie consent banner. "
            "Intended as a quick solution for sites that don't need a fully customisable consent."
        ),  # noqa
    )
    cookie_consent_deny_btn = models.BooleanField(
        default=False,
        verbose_name=_("Show Accept Necessary"),
        help_text=_(
            "Show an [Accept Necessary Only] button in the cookie consent banner. "
            "If unchecked, the banner will only have an accept and settings buttons."
        ),  # noqa
    )
    privacy_page = models.ForeignKey(
        "wagtailcore.Page",
        on_delete=models.CASCADE,
        related_name="+",
        blank=True,
        null=True,
        help_text=_(
            "Show a link to selected privacy policy page in cookie consent settings."
        ),
    )

    contact_page = models.ForeignKey(
        "wagtailcore.Page",
        on_delete=models.CASCADE,
        related_name="+",
        blank=True,
        null=True,
        help_text=_(
            "Show [More info] section with link to selected contact page in cookie consent settings."  # noqa
        ),
    )

    class ConsentModalLayout(models.TextChoices):
        BOX = "box"
        CLOUD = "cloud"
        BAR = "bar"

    consent_modal_layout = models.CharField(
        max_length=6,
        choices=ConsentModalLayout.choices,
        default=ConsentModalLayout.CLOUD,
        help_text=_("Layout of the cookie consent modal"),
    )

    class SettingsModalLayout(models.TextChoices):
        BOX = "box"
        BAR = "bar"

    settings_modal_layout = models.CharField(
        max_length=6,
        choices=SettingsModalLayout.choices,
        default=SettingsModalLayout.BOX,
        help_text=_("Layout of the full cookie consent settings modal."),
    )

    panels = [
        HelpPanel(
            heading=_("Know your tracking"),
            content=_(
                "<h3><b>Which tracking IDs do I need?</b></h3>"
                "<p>Most common choice is Google Analytics - but beware of "
                "GDPR compliance issues!. Matomo is a good alternative, "
                "and can be configured for GDPR compliance.</p>"
            ),
        ),
        MultiFieldPanel(
            [
                FieldPanel("g4_tracking_id"),
                FieldPanel("ga_track_button_clicks"),
            ],
            heading=_("Google Analytics"),
        ),
        MultiFieldPanel(
            [
                FieldPanel("gtm_id"),
            ],
            heading=_("Google Tag Manager"),
        ),
        MultiFieldPanel(
            [
                FieldPanel("matomo_site_id"),
                FieldPanel("matomo_hostname"),
                FieldPanel("matomo_disable_cookies"),
            ],
            heading=_("Matomo Analytics"),
        ),
        MultiFieldPanel(
            [
                FieldPanel("cookie_consent"),
                FieldPanel("cookie_consent_deny_btn"),
                FieldPanel("privacy_page"),
                FieldPanel("contact_page"),
                FieldPanel("consent_modal_layout"),
                FieldPanel("settings_modal_layout"),
            ],
            heading=_("Cookie consent"),
        ),
    ]


@register_setting(icon="cog")
class GeneralSettings(BaseSiteSetting):
    """
    Various site-wide settings. A good place to put
    one-off settings that don't belong anywhere else.
    """

    from_email_address = models.CharField(
        blank=True,
        max_length=255,
        verbose_name=_("From email address"),
        help_text=_(
            "The default email address this site appears to send from. "
            'For example: "sender@example.com" or '
            '"Sender Name <sender@example.com>" (without quotes)'
        ),
        # noqa
    )
    search_num_results = models.PositiveIntegerField(
        default=20,
        verbose_name=_("Number of results per page"),
    )
    external_new_tab = models.BooleanField(
        default=False, verbose_name=_("Open all external links in new tab")
    )

    gravatar = models.ForeignKey(
        get_image_model_string(),
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name="+",
        verbose_name=_("Gravatar Default"),
        help_text=_("Gravatar image when user email not found in gravatar db"),
    )

    panels = [
        MultiFieldPanel(
            [
                FieldPanel("from_email_address"),
            ],
            _("Email"),
        ),
        MultiFieldPanel(
            [
                FieldPanel("search_num_results"),
            ],
            _("Search Settings"),
        ),
        MultiFieldPanel(
            [
                FieldPanel("external_new_tab"),
            ],
            _("Links"),
        ),
        MultiFieldPanel(
            [
                FieldPanel("gravatar"),
            ],
            _("Avatar"),
        ),
    ]

    class Meta:
        verbose_name = _("General")


@register_setting(icon="mail")
class MailchimpApiSettings(BaseSiteSetting):
    """
    Settings for Mailchimp API services.
    """

    class Meta:
        verbose_name = _("Mailchimp API")

    mailchimp_api_key = models.CharField(
        blank=True,
        max_length=255,
        verbose_name=_("Mailchimp API Key"),
        help_text=_("The API Key used for Mailchimp."),
    )


@register_setting(icon="password")
class AdobeApiSettings(BaseSiteSetting):
    """
    Settings for Adobe PDF Embed services
    """

    adobe_embed_id = models.CharField(
        null=True,
        blank=True,
        max_length=64,
        verbose_name=_("Adobe Embed API ID"),
        help_text=_("Adobe PDF Embed API Client ID"),
    )



# Generated by Django 4.0.7 on 2022-08-13 15:17

import cjkcms.fields
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("cjkcms", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="articleindexpage",
            name="body",
            field=cjkcms.fields.CjkcmsStreamField(
                blank=True, null=True, use_json_field=True
            ),
        ),
        migrations.AlterField(
            model_name="articlepage",
            name="body",
            field=cjkcms.fields.CjkcmsStreamField(
                blank=True, null=True, use_json_field=True
            ),
        ),
        migrations.AlterField(
            model_name="webpage",
            name="body",
            field=cjkcms.fields.CjkcmsStreamField(
                blank=True, null=True, use_json_field=True
            ),
        ),
    ]



# Generated by Django 4.2.2 on 2023-07-03 18:00

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cjkcms", "0011_cjkcmspage_related_classifier_term_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="analyticssettings",
            name="ga_tracking_id",
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="matomo_disable_cookies",
            field=models.BooleanField(
                default=False,
                help_text="Disable Matomo cookies. Useful for GDPR compliance.",
                verbose_name="Disable Matomo Cookies",
            ),
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="matomo_hostname",
            field=models.CharField(
                blank=True,
                help_text="Matomo hostname (e.g. https://tracker.com). Without trailing slash.",
                max_length=128,
                verbose_name="Hostname (including http(s)://)",
            ),
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="matomo_site_id",
            field=models.IntegerField(
                blank=True,
                help_text="Numeric site id from Matomo website configuration.",
                null=True,
                verbose_name="Site ID",
            ),
        ),
    ]



# Generated by Django 4.2.2 on 2023-07-02 11:44

import cjkcms.fields
from django.db import migrations, models
import django.db.models.deletion
import modelcluster.fields
import wagtail_color_panel.fields


class Migration(migrations.Migration):
    dependencies = [
        ("wagtailimages", "0025_alter_image_file_alter_rendition_file"),
        ("cjkcms", "0009_navbar_language"),
    ]

    operations = [
        migrations.CreateModel(
            name="FilmStrip",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255, verbose_name="Name")),
            ],
            options={
                "verbose_name": "Film Strip",
            },
        ),
        migrations.CreateModel(
            name="FilmPanel",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "sort_order",
                    models.IntegerField(blank=True, editable=False, null=True),
                ),
                (
                    "background_color",
                    wagtail_color_panel.fields.ColorField(
                        blank=True, max_length=7, verbose_name="Background color"
                    ),
                ),
                (
                    "foreground_color",
                    wagtail_color_panel.fields.ColorField(
                        blank=True, max_length=7, verbose_name="Text color"
                    ),
                ),
                (
                    "custom_css_class",
                    models.CharField(
                        blank=True, max_length=255, verbose_name="Custom CSS class"
                    ),
                ),
                (
                    "custom_id",
                    models.CharField(
                        blank=True, max_length=255, verbose_name="Custom ID"
                    ),
                ),
                (
                    "content",
                    cjkcms.fields.CjkcmsStreamField(blank=True, use_json_field=True),
                ),
                (
                    "background_image",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to="wagtailimages.image",
                        verbose_name="Background image",
                    ),
                ),
                (
                    "film_strip",
                    modelcluster.fields.ParentalKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="film_panels",
                        to="cjkcms.filmstrip",
                        verbose_name="Film Panel",
                    ),
                ),
            ],
            options={
                "verbose_name": "Film Panel",
            },
        ),
    ]



from .cms_models import (
    ProjectArticlePage,
    ProjectArticleIndexPage,
    ProjectWebPage,
)

from cjkcms.models import WebPage, ArticleIndexPage, ArticlePage

# disable CjkCMS' default page types - we'll use our own
WebPage.max_count = 0
ArticleIndexPage.max_count = 0
ArticlePage.max_count = 0

__all__ = ["ProjectWebPage", "ProjectArticleIndexPage", "ProjectArticlePage"]



from .base import *  # noqa

DEBUG = False

# To send email from the server, we recommend django_sendmail_backend
# Or specify your own email backend such as an SMTP server.
# https://docs.djangoproject.com/en/{{ docs_version }}/ref/settings/#email-backend
EMAIL_BACKEND = "django_sendmail_backend.backends.EmailBackend"

# Use template caching to speed up wagtail admin and front-end.
# Requires reloading web server to pick up template changes.
TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
                "wagtail.contrib.settings.context_processors.settings",
            ],
            "loaders": [
                (
                    "django.template.loaders.cached.Loader",
                    [
                        "django.template.loaders.filesystem.Loader",
                        "django.template.loaders.app_directories.Loader",
                    ],
                ),
            ],
        },
    },
]

CACHES = {
    "default": {
        "BACKEND": "django.core.cache.backends.filebased.FileBasedCache",
        "LOCATION": os.path.join(BASE_DIR, "cache"),  # noqa
        "KEY_PREFIX": "cjkcms",
        "TIMEOUT": 14400,  # in seconds
    }
}

try:
    from .local import *  # noqa
except ImportError:
    pass



from .base import *  # noqa

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

ALLOWED_HOSTS = ["*"]

EMAIL_BACKEND = "django.core.mail.backends.console.EmailBackend"

WAGTAIL_CACHE = False

try:
    from .local import *  # noqa
except ImportError:
    print("Failed importing local settings")



# Generated by Django 4.0.7 on 2022-09-02 22:15

import cjkcms.fields
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("cjkcms", "0002_alter_body_to_cjkcmsstreamfield"),
    ]

    operations = [
        migrations.AlterField(
            model_name="footer",
            name="content",
            field=cjkcms.fields.CjkcmsStreamField(
                use_json_field=True, verbose_name="Content"
            ),
        ),
        migrations.AlterField(
            model_name="navbar",
            name="menu_items",
            field=cjkcms.fields.CjkcmsStreamField(
                use_json_field=True, verbose_name="Navigation links"
            ),
        ),
    ]



"""
Three main creatable page types used in Cjk CMS.
"""
from django.utils.translation import gettext_lazy as _
from cjkcms.models import (
    CjkcmsArticlePage,
    CjkcmsArticleIndexPage,
    CjkcmsWebPage,
)
from cjkcms.fields import CjkcmsStreamField
from cjkcms.blocks import LAYOUT_STREAMBLOCKS, CONTENT_STREAMBLOCKS
from home.blocks import (
    PROJECT_CONTENT_STREAMBLOCKS,
    PROJECT_LAYOUT_STREAMBLOCKS,
)

# add here custom blocks from other apps used in your project,
# so that they all can be part of the BODY of Web and Article pages.

ALL_CONTENT_STREAMBLOCKS = CONTENT_STREAMBLOCKS + PROJECT_CONTENT_STREAMBLOCKS

ALL_LAYOUT_STREAMBLOCKS = LAYOUT_STREAMBLOCKS + PROJECT_LAYOUT_STREAMBLOCKS


class ProjectArticlePage(CjkcmsArticlePage):
    """
    {{ uf_project }} Article, suitable for news or blog content.
    """

    class Meta:
        verbose_name = _("{{ uf_project }} Article")
        ordering = ["-first_published_at"]

    # Uncomment to only allow this page to be created beneath
    # an ArticleIndexPage, or ProjectArticleIndexPage
    # parent_page_types = ['website.ArticleIndexPage']

    # Override to CjkcmsStreamField to get rid of migration issues
    # when modifying CONTENT_STREAMBLOCKS.
    body = CjkcmsStreamField(
        ALL_CONTENT_STREAMBLOCKS, null=True, blank=True, use_json_field=True
    )

    # use cjkcms template by default
    template = "cjkcms/pages/article_page.html"
    search_template = "cjkcms/pages/article_page.search.html"
    search_filterable = True


class ProjectArticleIndexPage(CjkcmsArticleIndexPage):
    """
    Shows a list of article sub-pages.
    """

    # Override to CjkcmsStreamField to get rid of migration issues
    # when modifying LAYOUT_STREAMBLOCKS.
    body = CjkcmsStreamField(
        ALL_LAYOUT_STREAMBLOCKS, null=True, blank=True, use_json_field=True
    )

    class Meta:
        verbose_name = _("{{ uf_project }} Article Landing Page")

    index_order_by_default = ""

    # Override to specify custom index ordering choice/default.
    index_query_pagemodel = "home.ProjectArticlePage"

    # Only allow ArticlePages beneath this page.
    subpage_types = ["home.ProjectArticlePage", "cjkcms.ArticlePage"]

    # use cjkcms template by default
    template = "cjkcms/pages/article_index_page.html"


class ProjectWebPage(CjkcmsWebPage):
    """
    General use page with featureful streamfield and SEO attributes.
    """

    # Override to CjkcmsStreamField to get rid of migration issues
    # when modifying LAYOUT_STREAMBLOCKS.
    body = CjkcmsStreamField(
        ALL_LAYOUT_STREAMBLOCKS, null=True, blank=True, use_json_field=True
    )

    class Meta:
        verbose_name = _("{{ uf_project }} Web Page")

    # use cjkcms template by default
    template = "cjkcms/pages/web_page.html"



# Generated by Django 4.2.4 on 2023-08-19 16:03

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cjkcms", "0013_socialmediasettings_location"),
    ]

    operations = [
        migrations.AddField(
            model_name="navbar",
            name="alignment",
            field=models.CharField(
                blank=True,
                choices=[
                    ("me-auto", "Left (me-auto)"),
                    ("ms-auto", "Right (ms-auto)"),
                    ("mx-auto", "Center (mx-auto)"),
                    ("", "None"),
                ],
                default="me-auto",
                help_text="Force navbar alignment",
                max_length=32,
                verbose_name="Alignment",
            ),
        ),
    ]



from cjkcms.blocks.base_blocks import BaseBlock
from wagtail import blocks
from django.utils.translation import gettext_lazy as _


class PublicEventBlock(BaseBlock):
    """
    Entry to form a List of public events
    """

    title = blocks.CharBlock(
        required=True,
        max_length=255,
        label=_("Title"),
    )

    location = blocks.CharBlock(
        required=False,
        max_length=255,
        label=_("Location"),
        help_text=_("Country and city of the event"),
    )

    start_date = blocks.DateBlock(
        required=True,
        label=_("Start date"),
        help_text=_("Format: YYYY-MM-DD"),
    )

    end_date = blocks.DateBlock(
        required=False,
        label=_("End date"),
        help_text=_("Format: YYYY-MM-DD"),
    )

    description = blocks.RichTextBlock(
        features=["bold", "italic", "ol", "ul", "hr", "link", "document-link", "image"],
        label=_("Description"),
        help_text=_("Optional, short description of the event"),
        required=False,
    )

    url = blocks.URLBlock(
        max_length=255,
        label=_("Event website"),
        required=False,
    )

    hide_after_end_date = blocks.BooleanBlock(
        required=False,
        default=True,
        label=_("Hide after end date"),
        help_text=_("Hide this event after its end date"),
    )

    class Meta:
        template = "cjkcms/blocks/public_event_block.html"
        icon = "view"
        label = "Public Event"
        label_format = _("{title} (Event)")
